==> build-scripts-0.1.3.tgz: package/bin/child-process-start.js <==
#!/usr/bin/env node
const program = require('commander');
const detect = require('detect-port');
const inquirer = require('inquirer');
const parse = require('yargs-parser');

const getCliOptions = require('../lib/utils/getCliOptions');
const start = require('../lib/commands/start');
const log = require('../lib/utils/log');

program
  .allowUnknownOption()
  .option('--config <config>', 'use custom config')
  .option('-h, --host <host>', 'dev server host', '0.0.0.0')
  .option('-p, --port <port>', 'dev server port')
  .parse(process.argv);

const DEFAULT_PORT = program.port || process.env.PORT || 9999;
const defaultPort = parseInt(DEFAULT_PORT, 10);

(async () => {
  let newPort = await detect(defaultPort);
  if (newPort !== defaultPort) {
    const question = {
      type: 'confirm',
      name: 'shouldChangePort',
      message: `${defaultPort} 端口已被占用，是否使用 ${newPort} 端口启动？`,
      default: true,
    };
    const answer = await inquirer.prompt(question);
    if (!answer.shouldChangePort) {
      newPort = null;
    }
  }
  if (newPort === null) {
    process.exit(1);
  }

  process.env.NODE_ENV = 'development';
  const cliOptions = getCliOptions(program);
  cliOptions.port = parseInt(newPort, 10);
  const rawArgv = parse(process.argv.slice(2), { configuration: {'strip-dashed': true }});
  // ignore _ in rawArgv
  delete rawArgv._;
  try {
    const devServer = await start({
      args: {...rawArgv, ...cliOptions},
    });

    ['SIGINT', 'SIGTERM'].forEach(function(sig) {
      process.on(sig, function() {
        devServer.close();
        process.exit(0);
      });
    });
  } catch (err) {
    log.error(err.message);
    console.error(err);
    process.exit(1);
  }
})();

==> build-scripts-0.1.5-1.tgz: package/bin/child-process-start.js <==
#!/usr/bin/env node
const program = require('commander');
const detect = require('detect-port');
const inquirer = require('inquirer');
const parse = require('yargs-parser');

const getCliOptions = require('../dist/utils/getCliOptions');
const start = require('../dist/commands/start');
const log = require('../dist/utils/log');

program
  .allowUnknownOption()
  .option('--config <config>', 'use custom config')
  .option('-h, --host <host>', 'dev server host', '0.0.0.0')
  .option('-p, --port <port>', 'dev server port')
  .parse(process.argv);

const DEFAULT_PORT = program.port || process.env.PORT || 9999;
const defaultPort = parseInt(DEFAULT_PORT, 10);

(async () => {
  let newPort = await detect(defaultPort);
  if (newPort !== defaultPort) {
    const question = {
      type: 'confirm',
      name: 'shouldChangePort',
      message: `${defaultPort} 端口已被占用，是否使用 ${newPort} 端口启动？`,
      default: true,
    };
    const answer = await inquirer.prompt(question);
    if (!answer.shouldChangePort) {
      newPort = null;
    }
  }
  if (newPort === null) {
    process.exit(1);
  }

  process.env.NODE_ENV = 'development';
  const cliOptions = getCliOptions(program);
  cliOptions.port = parseInt(newPort, 10);
  const rawArgv = parse(process.argv.slice(2), { configuration: {'strip-dashed': true }});
  // ignore _ in rawArgv
  delete rawArgv._;
  try {
    const devServer = await start({
      args: {...rawArgv, ...cliOptions},
    });

    ['SIGINT', 'SIGTERM'].forEach(function(sig) {
      process.on(sig, function() {
        devServer.close();
        process.exit(0);
      });
    });
  } catch (err) {
    log.error(err.message);
    console.error(err);
    process.exit(1);
  }
})();
